import React, {useState} from "react";
import reg from "../assets/seller-reg/sellerreg.svg";
import { useNavigate } from "react-router-dom";

function Create_account() {
  const navigate = useNavigate();
  const Infoicon = () =>(
    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-5 h-5 inline-block ml-1">
    <path stroke-linecap="round" stroke-linejoin="round" d="M12 8v4m0 4h.01M12 20a8 8 0 100-16 8 8 0 000 16z" />
  </svg>
);
  const [phoneNumber, setPhoneNumber] = useState("");
  const [phoneNumberError, setPhoneNumberError] = useState("");

  const handlePhoneNumberChange = (e) => {
    const value = e.target.value;
    const phoneRegex = /^[0-9]{0,10}$/; // Allows only numbers and max 10 digits

    if (!phoneRegex.test(value)) {
      setPhoneNumberError("*Phone number must contain only numbers and be 10 digits.");
    } else {
      setPhoneNumberError("");
    }

    setPhoneNumber(value);
  };

  const handleSendOtp = (e) => {
    e.preventDefault();
    if (phoneNumber.length !== 10) {
      setPhoneNumberError("Phone number must be exactly 10 digits.");
    } else {
      setPhoneNumberError("");
      alert("OTP Sent Successfully!");
      navigate("/recive-otp", { state: { phone: phoneNumber } });
    }
  };
  return (
    <>
      <div className="flex flex-col items-center h-screen bg-[#E9FAFF] px-6 py-4 font-montserrat">
      {/* Header */}
      <div className="w-full text-left max-w-6xl px-2 md:px-0 mb-6 mt-6 ml-30 flex">
        <h1 className="text-4xl font-font-primary font-bold text-[#030A1E] mb-6 text-left w-full max-w-[90%]">
          OMPOI - Seller
        </h1>
      </div>

      <div className="bg-[#FFFFFF] p-6 rounded-[32.6px] shadow-lg w-[90%] h-[85%] flex flex-col md:flex-row py-8 mb-5 ">
        {/* Left Section - Image */}
        <div className="hidden md:flex w-1/2 items-center justify-center p-4 min-w-[300px]">
          <img src={reg} alt="Login Illustration" className="w-[80%] lg:w-[80%] xl:w-[80%]" />
        </div>
        <div className="w-[1px]  bg-[#C4CFDE] hidden md:block" />

        {/* Right Section - OTP Registration */}
        <div className="w-full md:w-1/2 flex flex-col items-center justify-start p-6 text-[#030A1E] mt-12">
          <h2 className="text-4xl md:text-3xl font-font-primary font-semibold text-[7DEBD9] mb-3 -mt-6 md:mb-6">
            Merchant Registration
          </h2>
          <p className="text-3xl md:text-2xl font-bold mt-[5px] justify-center items-center self-center mb-3 md:mb-15">
            OTP-Verification
          </p>

          <form className="w-full max-w-md " onSubmit={handleSendOtp}>
            <div className="relative w-full mb-8">
              <div className="relative border-2 rounded-lg border-[#C4CFDE] bg-transparent">
                <label
                  className={`absolute -top-3 left-4 px-2 bg-[#C4CFDE] border border-[#C4CFDE] rounded-md text-sm text-[#45505F] font-font-primary font-medium ${
                    phoneNumberError ? "text-red-500" : "text-green-500"
                  }`}
                >
                  Phone Number
                </label>
                <input
                    type="text"
                    id="phoneNumber"
                    value={phoneNumber}
                    onChange={handlePhoneNumberChange}
                    maxLength="10"
                    required
                    className={`w-full h-14 px-3 pr-12 bg-transparent text-[#45505F] text-lg focus:outline-none font-font-primary ${phoneNumberError ? "border-red-500" : "border-green-500 "} `}
                    placeholder="+91"
                  />
                {phoneNumberError && (
                  <p className="text-red-500 text-[10px] mt-1">{phoneNumberError} <Infoicon /> </p>
                )}
              </div>
              
            </div>

            <div className="flex justify-center items-center">
              <button
                type="submit"
                className="w-[100%] md:w-48 h-14 text-[#030A1E]  rounded-full bg-[#FFBD69] shadow-md hover:bg-orange-500 transition text-lg font-font-primary font-extrabold"
              >
                Send OTP
              </button>
            </div>
          </form>
          <div className="hidden md:flex ml-[128%] mt-[-65%]">
            <div className="border-[2px] border-[#171451] right-5  w-10 h-10 bg-[#E2E7EE] rounded-full" />
              <div className="rounded-full bg-[#171451] p-1 w-5 h-5 mx-[-30px] my-[10px] ">
                <div className="w-[1px] h-[120px] mt-[25px] ml-[5px] bg-[#D1D5DB] border-dotted border-[1px]" >
                  <div className="border-[2px] border-[#D1D5DB] right-5  w-10 h-10 mt-[120px] ml-[-20px] bg-[#E2E7EE] rounded-full ">
                  <div className="rounded-full bg-[#D1D5DB] p-1 w-5 h-5 mx-[8px] my-[8px] ">
                    <div className="w-[1px] h-[120px] mt-[25px] ml-[5px] bg-[#D1D5DB] border-dotted border-[1px] ">
                      <div className=" border-[2px] border-[#D1D5DB] right-5  w-10 h-10 mt-[120px] ml-[-20px] bg-[#E2E7EE] rounded-full ">
                      <div className="rounded-full bg-[#D1D5DB] p-1 w-5 h-5 mx-[8px] my-[8px] ">
                      </div>  
                      </div>
                    </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
        </div>
        </div>

        {/* Absolute right-side design, hidden on small screens */}
        
    </div>
</>
  );
}

export default Create_account;
