import React, { useState } from "react";
import key from "../assets/seller-login/first!.svg";
import icon from "../assets/seller-login/mail.svg";
import icon1 from "../assets/seller-login/eye.svg";
import icon2 from "../assets/seller-login/open-eye.svg";
import { useNavigate } from "react-router-dom";

function Seller_login() {
  const navigate = useNavigate();
        const goto = () => {
            navigate("/create-account");
        };
  const Infoicon = () =>(
    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-5 h-5 inline-block ml-1">
    <path stroke-linecap="round" stroke-linejoin="round" d="M12 8v4m0 4h.01M12 20a8 8 0 100-16 8 8 0 000 16z" />
  </svg>
);
  const [merchantId, setMerchantId] = useState("");
  const [password, setPassword] = useState("");
  const [merchantIdError, setMerchantIdError] = useState("");
  const [passwordError, setPasswordError] = useState("");
  const [showPassword, setShowPassword] = useState(false);

  const validateMerchantId = (id) => {
    const pattern = /^[A-Za-z]{4}\d{5}$/;
    if (!pattern.test(id)) {
      setMerchantIdError("*Merchant ID must be 4 letters followed by 5 numbers");
      return false;
    }
    setMerchantIdError("");
    return true;
  };

  const validatePassword = (pass) => {
    const pattern = /^(?=.*[a-zA-Z]{4,})(?=.*\d{3,})(?=.*[^a-zA-Z\d]{2,}).{9,}$/;
    if (!pattern.test(pass)) {
      setPasswordError(
        "*Password must contain at least 4 letters, 2 special characters, and 3 numbers"
      );
      return false;
    }
    setPasswordError("");
    return true;
  };

  return (
    <div className="flex flex-col items-center h-screen bg-[#E9FAFF] px-6 py-4 font-montserrat">
      {/* Header */}
       <h1 className="text-4xl font-font-primary font-bold text-[#030A1E] mb-8 text-left w-full max-w-[90%]">OMPOI - Seller</h1>
       <div className="bg-[#FFFFFF] p-10 rounded-[32.6px] shadow-lg w-[90%] h-[85%] flex flex-col md:flex-row py-[-12%] ">
        {/* Left Section - Image */}
        <div className="hidden md:flex w-1/2 items-center justify-center p-4 min-w-[300px]">
          <img src={key} alt="Login Illustration" className="w-[80%] lg:w-[80%] xl:w-[80%]" />
        </div>
        <div className="w-[1px]  bg-[#C4CFDE] hidden md:block "></div>

        {/* Right Section - Login Form */}
        <div className="w-full md:w-1/2 flex flex-col items-center justify-start p-6 text-[#030A1E] mt-12">
          <h2 className="text-4xl md:text-3xl font-font-primary font-semibold text-[7DEBD9] mb-10 -mt-10 md:mb-10 ">Login</h2>

          <form className="w-full max-w-md">
            <div className="relative w-full mb-8">
              <div className="relative border-2 rounded-lg border-[#C4CFDE] bg-transparent">
                    <label
                      className={`absolute -top-3 left-4 px-2 bg-[#C4CFDE] border border-[#C4CFDE] rounded-md text-sm text-[#45505F] font-font-primary font-medium  ${
                        merchantIdError ? "text-red-500" : "text-green-500"
                      }`}
                    >
                      Merchant ID
                    </label>
                    <input
                      type="text"
                      id="merchantId"
                      className={`w-full h-14 px-3 pr-12 bg-transparent text-[#45505F] text-lg focus:outline-none font-font-primary ${
                        merchantIdError ? "border-red-500" : "border-green-500 "
                      }`}
                      required
                      placeholder="Enter ID"
                      value={merchantId}
                      onChange={(e) => {
                        setMerchantId(e.target.value);
                        validateMerchantId(e.target.value);
                      }}
                    />
                <span className="flex inset-y-0 justify-end">
                  <img src={icon} alt="icon" className="relative items-center w-3 md:w-5 h-3 md:h-5 mt-[-25px] md:mt-[-35px] mr-[12px] md:mr-[20px]" />
                </span>
                {merchantIdError && <p className="text-red-500 text-[10px]">{merchantIdError} <Infoicon /> </p>}
              </div>
            </div>

            <div className="relative w-full mb-2">
              <div className="relative border-2 rounded-lg border-[#C4CFDE] bg-transparent ">
                      <label
                      className={`absolute -top-3 left-4 px-2 bg-[#C4CFDE] border border-[#C4CFDE] rounded-md text-sm font-font-primary font-medium text-[#C4CFDE] ${
                        passwordError ? "text-red-500" : "text-green-500"
                      }`}
                    >
                      Password
                    </label>
                    <input
                      type={showPassword ? "text" : "password"}
                      id="password"
                      className={`w-full h-14 px-4 pr-12 bg-transparent text-[#45505F] text-lg focus:outline-none font-font-primary ${
                        passwordError ? "border-red-500" : "border-green-500 " 
                      }`}
                      required
                      placeholder="Enter your password"
                      value={password}
                      onChange={(e) => {
                        setPassword(e.target.value);
                        validatePassword(e.target.value);
                      }}
                    />
                    <span className="flex inset-y-0 justify-end cursor-pointer" onClick={() => setShowPassword(!showPassword)}>
                      <img src={showPassword ? icon2 : icon1} alt="icon" className="relative items-center w-3 md:w-5 h-3 md:h-5 mt-[-25px] md:mt-[-35px] mr-[12px] md:mr-[20px]" />
                    </span>
                    {passwordError && <p className="text-red-500 text-[10px]">{passwordError} <Infoicon /></p>}
                  </div>
            </div>


            <div className="flex justify-between w-full text-sm mb-4">
              <p className="text-[#030A1E] text-[10px] md:text-[12px]  hover:underline cursor-pointer" >Forgot Password?</p>
              <p className="text-[#FFBD69] text-[10px] md:text-[12px] hover:underline cursor-pointer" onClick={goto} >Create an Account</p>
            </div>
            <div className="mt-8 flex justify-center">
              <button className="p-4 w-[100%] md:w-48 h-14 text-[#030A1E]  rounded-full bg-[#FFBD69] shadow-md hover:bg-orange-500 transition text-lg font-font-primary font-extrabold">
                Sign in
              </button>
            </div>
            {/*Check Status button  */}
            <div className="mt-3 flex justify-center">
              <button className="p-4  w-[100%] md:w-48 h-14 text-[#030A1E] font-bold rounded-full bg-[#FFffff] border-[#FFBD69] border-2 shadow-md hover:bg-orange-500 transition text-lg font-font-primary md:font-extrabold">
                Check Status
              </button>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}

export default Seller_login;
